pub fn parse_file(path: &Path) -> Result<ComposeFile>Expand description
Parse a compose file from disk, applying variable substitution and
resolving extends: / include: directives.
pub fn parse_file(path: &Path) -> Result<ComposeFile>Parse a compose file from disk, applying variable substitution and
resolving extends: / include: directives.